# Wall E

<p align="center" text-align="center">

[![pipeline status](https://gitlab.com/bootstrapped-learners/wall-e/badges/main/pipeline.svg)](https://gitlab.com/bootstrapped-learners/wall-e/-/commits/main) [![coverage report](https://gitlab.com/bootstrapped-learners/wall-e/badges/main/coverage.svg)](https://gitlab.com/bootstrapped-learners/wall-e/-/commits/main) [![Latest Release](https://gitlab.com/bootstrapped-learners/wall-e/-/badges/release.svg)](https://gitlab.com/bootstrapped-learners/wall-e/-/releases) 

</p>
